﻿using UnityEngine;
using UnityEditor;
using System.IO;
using System.Collections;
using System.Collections.Generic;
using System.Text.RegularExpressions;
using System.Text;

using System.Xml;


enum ToolState {Initial, Finished, Error};


public class EventGen : EditorWindow
{


	EventDB EventDBAsset; 
	string ErrorText;
	string SuccessText;
	ToolState toolState = ToolState.Initial;

	Color BackgroundColor = new Color32(0,0,0,0);
	Color FontColor = new Color32(255,255,255,255);



	// Dictionary containing unifont data
	private Dictionary <int, string> hexFontDictionary = new Dictionary<int, string>();

    // Add menu to the Window menu
    [MenuItem("Window/EventGen")]
    static void Init()
    {
        // Get existing open window or if none, make a new one:
		EventGen window = (EventGen)EditorWindow.GetWindow(typeof(EventGen));
        window.Show();


    }

	 


    void ShowLoadXMLView(){
		//Debug.Log("UniGen::ShowLoadXMLView!");

		GUILayout.Label("Load xml file containing event-data", EditorStyles.boldLabel);
		if(GUILayout.Button("Select file")) {
			string path = EditorUtility.OpenFilePanel("Open XML file", "", "xml");
	        if (path.Length != 0)
	        {
				try{
					string xmlDataString;

					StreamReader reader = new StreamReader(path); 
					xmlDataString = reader.ReadToEnd();
					reader.Close();

					EventData eventData = ScriptableObject.CreateInstance(typeof(EventData)) as EventData;
					eventData.PopulateEventList(xmlDataString);
					ProjectWindowUtil.CreateAsset(eventData, Path.GetFileName(path)+".asset");
					toolState = ToolState.Finished;
					SuccessText = "Created Asset with name:"+Path.GetFileName(path)+".asset";
				}catch(XmlException ex){
					Debug.Log("Failed to populate EventList from the xml file:"+path);
					Debug.Log("Exception"+ ex.ToString());
					toolState = ToolState.Error;
					ErrorText = ex.ToString();
					return;
				}
			}
	        

		}

		
		GUILayout.Label(SuccessText, EditorStyles.boldLabel);

    }

	void ShowErrorView(){
		GUILayout.Label("Error within the file:", EditorStyles.boldLabel);
		GUILayout.Label(ErrorText, EditorStyles.boldLabel);


	}



    void OnGUI()
    {
		switch(toolState){
			case ToolState.Initial:
				ShowLoadXMLView();
			break;

			case ToolState.Finished:
				ShowLoadXMLView();
			break;

			case ToolState.Error:
				ShowErrorView();
			break;
		}


    }
}