﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;


/// <summary>
/// Static class for providing methods, that allow accessing GameObject's components in more easy way
/// </summary>
public static class AccessHelper {

    /// <summary>
    /// Static class for accessing Database components
    /// </summary>
	public static class Database {

		public static GameObject GetDatabase(){
			GameObject databaseGO = GameObject.Find("Database");
			if(!databaseGO){
				Debug.LogWarning("AccessHelper: Failed to find Database object");
				return null;
			}
			return databaseGO;
		}


		/// <summary>
		/// Gets EventDB component from the Database GameObject
		/// </summary>
		/// <returns>Returns EventDB component.</returns>
		public static EventDB GetEventDB(){
			EventDB eventDB = (EventDB) GetDatabase().GetComponent(typeof(EventDB));
			if(!eventDB){
				Debug.LogWarning("AccessHelper: Failed to retrieve Database->eventDB");
				return null;
			}
			return eventDB;
		}

	}

	/// <summary>
	/// Static class for accessing GameState objects (GO) components.
	/// </summary>
	public static class GameStates {

		/// <summary>
		/// Returns the GameState (GO) object .
		/// </summary>
		/// <returns>GameState GameObject.</returns>
		public static GameObject GetGameStates(){
			GameObject gameStateGO = GameObject.Find("GameStates");
			if(!gameStateGO){
				Debug.LogWarning("AccessHelper: Failed to find Database object");
				return null;
			}
			return gameStateGO;
		}

		/// <summary>
		/// Gets the PlayerState component from the GameState GameObject.
		/// </summary>
		/// <returns>The PlayerState component.</returns>
		public static PlayerState GetPlayerState(){
			PlayerState playerState = (PlayerState) GetGameStates().GetComponent(typeof(PlayerState));
			if(!playerState){
				Debug.LogWarning("AccessHelper: Failed to retrieve GameState->playerState");
				return null;
			}
			return playerState;
		}
	}

	public static class GameGUI {
		public static GameObject GetGameGUI(){
			GameObject gameGUIGO = GameObject.Find("GameGUI");
			if(!gameGUIGO){
				Debug.LogWarning("AccessHelper: Failed to find GameGUI object");
				return null;
			}
			return gameGUIGO;
		}


		public static EventViewController GetEventViewController(){
			EventViewController eventViewController = GetGameGUI().GetComponentInChildren<EventViewController>();
			if(!eventViewController){
				Debug.LogWarning("AccessHelper: Failed to retrieve GameGUI->eventViewController");
				return null;
			}
			return eventViewController;
		}

		public static StartViewController GetStartViewController(){
			StartViewController startViewController = GetGameGUI().GetComponentInChildren<StartViewController>();
			if(!startViewController){
				Debug.LogWarning("AccessHelper: Failed to retrieve GameGUI->startViewController");
				return null;
			}
			return startViewController;
		}

		public static TimeAdvanceViewController GetTimeAdvanceViewController(){
			TimeAdvanceViewController timeAdvanceViewController = GetGameGUI().GetComponentInChildren<TimeAdvanceViewController>();
			if(!timeAdvanceViewController){
				Debug.LogWarning("AccessHelper: Failed to retrieve GameGUI->timeAdvanceViewController");
				return null;
			}
			return timeAdvanceViewController;
		}

		public static LoseViewController GetLoseViewController() {
			LoseViewController loseViewController = GetGameGUI().GetComponentInChildren<LoseViewController>();
			return loseViewController;
		}

		public static WinViewController GetWinViewController() {
			WinViewController winViewController = GetGameGUI().GetComponentInChildren<WinViewController>();
			return winViewController;
		}
	}


	public static class GameLogic {
		public static GameObject GetGameLogic() {
			GameObject game = GameObject.Find("GameStates");
			if (!game) {
				Debug.LogWarning("AccessHelper: Failed to find GameStates object");
				return null;
			}

			return game;
		}

		public static GameScript GetGameScript() {
			GameScript gameScript = GetGameLogic().GetComponentInChildren<GameScript>();
			if (!gameScript) {
				Debug.LogWarning("AccessHelper: Failed to retrieve GameStates->GameScript");
				return null;
			}
			return gameScript;
		}

		public static VacationTime GetVacationTime() {
			VacationTime script = GetGameLogic().GetComponentInChildren<VacationTime>();
			if (!script) {
				Debug.LogWarning("AccessHelper: Failed to retrieve VacationTime");
				return null;
			}
			return script;
		}
	}
	

	
	public static class Audio {

		public static GameObject GetAudio(){
			GameObject audioGO = GameObject.Find("Audio");
			if(!audioGO){
				Debug.LogWarning("AccessHelper: Failed to find GameGUI object");
				return null;
			}
			return audioGO;
		}


		public static EventEffectAudio EventAudioPlayer(){
			EventEffectAudio eventEffectAudio = GetAudio().GetComponentInChildren<EventEffectAudio>();
			if(!eventEffectAudio){
				Debug.LogWarning("AccessHelper: Failed to retrieve Audio->eventEffectAudio");
				return null;
			}
			return eventEffectAudio;
		}
	}


	


}
