﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using System.Reflection;
using System;

public class EventViewController : BaseView {

	private Text m_TitleText;
	private Text m_DescriptionText;
	private Image m_EventImage;
	private RectTransform m_ActionPanelRectTransform;
	private GameObject m_ActionPanelGO;
	private Event m_Event;


	void Awake(){

		m_TitleText = (Text) transform.Find("BGPanel/EventPanel/TitlePanel/TitleText").gameObject.GetComponent(typeof(Text));
		m_DescriptionText = (Text) transform.Find("BGPanel/EventPanel/DescriptionText").gameObject.GetComponent(typeof(Text));
		m_ActionPanelGO = transform.Find("BGPanel/EventPanel/ActionPanel").gameObject;
		m_ActionPanelRectTransform = (RectTransform) m_ActionPanelGO.GetComponent(typeof(RectTransform));
		m_EventImage = transform.Find("BGPanel/EventImage").gameObject.GetComponent<Image>();
	}
	
	// Update is called once per frame
	void Update () {
		
	}

	public void StartEvent(string eventId){

		foreach(Transform child in m_ActionPanelGO.transform){
			Debug.LogWarning("EventViewController::Destroying button->:"+child.name);
			GameObject.Destroy(child.gameObject);
		}


		m_Event = AccessHelper.Database.GetEventDB().GetEvent(eventId);
		
		Sprite eventSprite = Resources.Load<Sprite>("events/images/"+m_Event.Screen);

		if(eventSprite == null){
			Debug.Log("No sprite available");
			eventSprite = Resources.Load<Sprite>("events/images/404");
		}
		m_EventImage.sprite = eventSprite;
		
		AccessHelper.Audio.EventAudioPlayer().PlayEffect(m_Event.sfx);

		if(m_Event==null){
			Debug.Log("Event is not existing");
		}
		Debug.Log("EventViewController::StartEvent() called with-> event:"+m_Event.ToString());

		m_TitleText.text = m_Event.Title;
		m_DescriptionText.text = m_Event.Description;

		int actionIndex = 0;
		foreach(EventAction action in m_Event.ActionList){
			GameObject actionButton = (GameObject)Instantiate(Resources.Load("prefabs/ActionButton"));
			actionButton.transform.SetParent(m_ActionPanelRectTransform, false);
			actionButton.transform.localScale = new Vector3(1,1,1);
			Button tempButton = actionButton.GetComponent<Button>();
			
			tempButton.GetComponentInChildren<Text>().text = action.Title;
			

			Debug.Log("Adding listener: Current index:"+actionIndex.ToString());

			// Without using tempActionIndex, the index will be wrong always
			int tempActionIndex = actionIndex;
			tempButton.onClick.AddListener(() => ActionButtonClicked(tempActionIndex));

			actionIndex++;
		}

		ShowView(true);
	}

	// TODO Remember to destroy the listeneres against this function!
	void ActionButtonClicked(int actionIndex){
		Debug.Log("ActionButton clicked->index:"+actionIndex.ToString());
		Debug.Log("Current event:"+m_Event.ToString());
		Debug.Log("Action causes:"+m_Event.ActionList[actionIndex].CauseList.Count.ToString());
		Debug.Log("Action effects:"+m_Event.ActionList[actionIndex].EffectList.Count.ToString());

		//typeof(EventActionHandler.CauseCall).GetMethod("hide_valuables").Invoke(null,null);



		// Iterate trough the causelist and invoke the method from EventActionHandler
		List<EventCause> causeList = m_Event.ActionList[actionIndex].CauseList;
		foreach(EventCause cause in causeList){
			try{
				Debug.Log("EventViewController::ActionButtonClicked() -> Calling method:"+cause.Id);
				typeof(EventActionHandler.CauseCall).GetMethod(cause.Id).Invoke(null,cause.GetArgArray());
			}catch(NullReferenceException e){
				Debug.Log("Failed to make a CauseCall against method:"+cause.Id+", details:"+e.ToString());
			}
		}


		// Iterate trough the effects list and invoke the method from EventActionHandler
		List<EventEffect> effectList = m_Event.ActionList[actionIndex].EffectList;
		foreach(EventEffect effect in effectList){
			try{
				Debug.Log("EventViewController::ActionButtonClicked() -> Calling method:"+effect.Id);
				typeof(EventActionHandler.EffectCall).GetMethod(effect.Id).Invoke(null, effect.GetArgArray());
			}catch(NullReferenceException e){
				Debug.Log("Failed to make a EffectCall against method:"+effect.Id+", details:"+e.ToString());
			}
		}



	}

}
