﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class TimeAdvanceViewController : BaseView
{
    public Transform HourHand;
    public Transform MinuteHand;
    public Image Window;

    public Sprite Night;
    public Sprite EarlyMorning;
    public Sprite Morning;
    public Sprite Day;

    private bool m_newDay = true;
    private List<string> m_tags;

    public int LastHour = 0;
    public int LastMinutes = 0;
    public int MinutesCounter = 0;
    public int MinutesToNextEvent = 0;
    // Start is called before the first frame update
    void Start()
    {
        Reset();
    }

    public void Reset() {
        m_tags = new List<string>() {
                "morning"
            };
       MinutesToNextEvent = (int)(Random.value * 120 + 6 * 60);
       MinutesCounter = 0;
       LastHour = 0;
       LastMinutes = 0;
    }

    // Update is called once per frame
    void Update()
    {
        if (AccessHelper.GameLogic.GetGameScript().CurrentState != GameScript.GameState.TIME_ADVANCE)
            return;

        VacationTime clock = AccessHelper.GameLogic.GetVacationTime();

        if (clock.Hours < 6) {
            Window.sprite = Night;
        } else if (clock.Hours < 7) {
            Window.sprite = EarlyMorning;
        } else if (clock.Hours < 10) {
            Window.sprite = Morning;
        } else {
            Window.sprite = Day;
        }

        int hour = (clock.Hours < 12) ? -clock.Hours : -clock.Hours + 12;
        HourHand.localRotation = Quaternion.Euler(0, 0, (360f / 12f * hour) + (30f / 60f * -clock.Minutes));
        MinuteHand.localRotation = Quaternion.Euler(0, 0, (360f / 60f * -clock.Minutes));


        if (clock.Hours == 23 && clock.Minutes == 59)
        {
            AccessHelper.GameLogic.GetGameScript().CurrentState = GameScript.GameState.WIN;
            return;
        }

        MinutesCounter = (clock.Hours - LastHour) * 60 + clock.Minutes - LastMinutes;

        if (MinutesCounter < MinutesToNextEvent)
            return;

        // Get random event
        if (clock.Hours > 6 && clock.Hours < 12 && m_tags.Contains("morning"))
        {
            string id = AccessHelper.Database.GetEventDB().GetRandomRootEvent("morning").Id;
            AccessHelper.GameGUI.GetEventViewController().StartEvent(id);
            AccessHelper.GameLogic.GetGameScript().CurrentState = GameScript.GameState.EVENT;
            m_tags.Remove("morning");
        }
        else if (clock.Hours > 9 && clock.Hours < 23)
        {
            string id = AccessHelper.Database.GetEventDB().GetRandomRootEventExcluding(new List<string>() { "morning" }).Id;
            AccessHelper.GameGUI.GetEventViewController().StartEvent(id);
            AccessHelper.GameLogic.GetGameScript().CurrentState = GameScript.GameState.EVENT;
        }

        LastHour = clock.Hours;
        LastMinutes = clock.Minutes;

        MinutesToNextEvent = Mathf.Clamp((int)(180 * Random.value), 40, 120);
    }
}
